#include <stdio.h>
#include <recGbl.h>
#include <devSup.h>
#include <alarm.h>
#include <dbAccess.h>
#include <waveformRecord.h>

long devIntegrateWaveformInit(waveformRecord *record)
{
    switch (record->inp.type) {
        case (PV_LINK):
        case (DB_LINK):
        case (CA_LINK):
            break;
        default:
            recGblRecordError(S_db_badField, record,
                "devIntegrateWaveform (init record) Illegal INP field");
            return S_db_badField;
    }
    return 0;
}

long devIntegrateWaveformRead(waveformRecord *record)
{
    long status, n, i;
    
    n = record->nelm;
    status = dbGetLink(&record->inp, record->ftvl, record->bptr, 0, &n);
    if (status) {
        recGblSetSevr(record, READ_ALARM, INVALID_ALARM);
        return status;
    }
    record->nord = n;
    switch (record->ftvl) {
        case DBF_DOUBLE: {
            double sum = 0.0;
            printf ("%s: integrating %ld DOUBLE\n",
                record->name, n);
            for (i=0; i<n; i++) {
                sum += ((double*)(record->bptr))[i];
                ((double*)(record->bptr))[i] = sum;
            }
            break;
        }
        default:
            recGblSetSevr(record, UDF_ALARM, INVALID_ALARM);
            recGblRecordError(S_db_badField, record,
                "devIntegrateWaveform Illegal FTVL field");
            return ERROR;
    }
    return 0;
}
struct {
    long number;
    DEVSUPFUN report;
    DEVSUPFUN init;
    DEVSUPFUN init_record;
    DEVSUPFUN get_ioint_info;
    DEVSUPFUN read;
} devIntegrateWaveform = {
    5,
    NULL,
    NULL,
    devIntegrateWaveformInit,
    NULL,
    devIntegrateWaveformRead
};

